@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -112,7 +112,7 @@ GLDEF(HDC, wglGetCurrentDC, (void));
 GLDEF(int, GetDeviceCaps, (HDC, int));
 
 #define INJDEF(ret, name, arg) GLDEF(ret, name, arg); static HardHook hh##name
-#define INJECT(name) { o##name = reinterpret_cast<t##name>(GetProcAddress(hGL, #name)); if (o##name) { hh##name.setup(reinterpret_cast<voidFunc>(o##name), reinterpret_cast<voidFunc>(my##name)); hh##name.inject(); } else { ods("OpenGL: No GetProc for %s", #name);} }
+#define INJECT(name) { o##name = reinterpret_cast<t##name>(GetProcAddress(hGL, #name)); if (o##name) { hh##name.setup(reinterpret_cast<voidFunc>(o##name), reinterpret_cast<voidFunc>(my##name)); o##name = (t##name) hh##name.call; } else { ods("OpenGL: No GetProc for %s", #name);} }
 
 INJDEF(BOOL, wglSwapLayerBuffers, (HDC, UINT));
 INJDEF(BOOL, wglSwapBuffers, (HDC));
@@ -124,6 +124,7 @@ static bool bChaining = false;
 struct Context {
 	HGLRC ctx;
 	GLuint textures[NUM_TEXTS];
+	unsigned int uiCounter[NUM_TEXTS];
 	Context(HDC hdc);
 	void draw(HDC hdc);
 };
@@ -171,15 +172,13 @@ Context::Context(HDC hdc) {
 	if (dwWaitResult != WAIT_OBJECT_0)
 		return;
 
-	for (int i = 0; i < NUM_TEXTS; i++) {
-		sm->texts[i].bUpdated = true;
-	}
+	for (int i=0;i<NUM_TEXTS;++i)
+		uiCounter[i] = 0;
 
 	ReleaseMutex(hSharedMutex);
 }
 
 void Context::draw(HDC hdc) {
-	bVideoHooked = true;
 	sm->bHooked = true;
 
 	// DEBUG
@@ -228,7 +227,7 @@ void Context::draw(HDC hdc) {
 		if (sm->texts[i].width == 0) {
 			y += iHeight / 4;
 		} else if (sm->texts[i].width > 0) {
-			if (sm->texts[i].bUpdated) {
+			if (sm->texts[i].uiCounter != uiCounter[i]) {
 				ods("OpenGL: Updating %d %d texture", sm->texts[i].width, TEXT_HEIGHT);
 				oglBindTexture(GL_TEXTURE_2D, textures[i]);
 				oglTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
@@ -236,7 +235,7 @@ void Context::draw(HDC hdc) {
 				oglTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
 				oglTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
 				oglTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, TEXT_WIDTH, TEXT_HEIGHT, 0, GL_BGRA, GL_UNSIGNED_BYTE, sm->texts[i].texture);
-				sm->texts[i].bUpdated = false;
+				uiCounter[i] = sm->texts[i].uiCounter;
 			}
 			texs[idx] = textures[i];
 			widths[idx] = sm->texts[i].width;
@@ -309,7 +308,6 @@ void Context::draw(HDC hdc) {
 	}
 }
 
-
 static map<HDC, Context *> contexts;
 
 static void doSwap(HDC hdc) {
@@ -372,47 +370,43 @@ void checkOpenGLHook() {
 		if (! bHooked) {
 			char procname[1024];
 			GetModuleFileName(NULL, procname, 1024);
-			ods("OpenGL: CreateWnd in unhooked OpenGL App %s", procname);
+			fods("OpenGL: Unhooked OpenGL App %s", procname);
 			bHooked = true;
 
-			if (strstr(procname, "mumble.exe") != NULL) {
-				ods("OpenGL: Ignoring mumble.exe");
+			INJECT(wglSwapBuffers);
+			// INJECT(wglSwapLayerBuffers);
+
+			GLDEF(wglCreateContext);
+			GLDEF(glGenTextures);
+			GLDEF(glEnable);
+			GLDEF(glDisable);
+			GLDEF(glBlendFunc);
+			GLDEF(glColorMaterial);
+			GLDEF(glViewport);
+			GLDEF(glMatrixMode);
+			GLDEF(glLoadIdentity);
+			GLDEF(glOrtho);
+			GLDEF(glBindTexture);
+			GLDEF(glPushMatrix);
+			GLDEF(glColor4ub);
+			GLDEF(glTranslatef);
+			GLDEF(glBegin);
+			GLDEF(glEnd);
+			GLDEF(glTexCoord2f);
+			GLDEF(glVertex2f);
+			GLDEF(glPopMatrix);
+			GLDEF(glTexParameteri);
+			GLDEF(glTexImage2D);
+			GLDEF(wglMakeCurrent);
+			GLDEF(wglGetCurrentContext);
+			GLDEF(wglGetCurrentDC);
+
+			hGL = GetModuleHandle("GDI32.DLL");
+			if (hGL) {
+				// INJECT(SwapBuffers);
+				GLDEF(GetDeviceCaps);
 			} else {
-				INJECT(wglSwapBuffers);
-				// INJECT(wglSwapLayerBuffers);
-
-				GLDEF(wglCreateContext);
-				GLDEF(glGenTextures);
-				GLDEF(glEnable);
-				GLDEF(glDisable);
-				GLDEF(glBlendFunc);
-				GLDEF(glColorMaterial);
-				GLDEF(glViewport);
-				GLDEF(glMatrixMode);
-				GLDEF(glLoadIdentity);
-				GLDEF(glOrtho);
-				GLDEF(glBindTexture);
-				GLDEF(glPushMatrix);
-				GLDEF(glColor4ub);
-				GLDEF(glTranslatef);
-				GLDEF(glBegin);
-				GLDEF(glEnd);
-				GLDEF(glTexCoord2f);
-				GLDEF(glVertex2f);
-				GLDEF(glPopMatrix);
-				GLDEF(glTexParameteri);
-				GLDEF(glTexImage2D);
-				GLDEF(wglMakeCurrent);
-				GLDEF(wglGetCurrentContext);
-				GLDEF(wglGetCurrentDC);
-
-				hGL = GetModuleHandle("GDI32.DLL");
-				if (hGL) {
-					// INJECT(SwapBuffers);
-					GLDEF(GetDeviceCaps);
-				} else {
-					ods("OpenGL: Failed to find GDI32");
-				}
+				ods("OpenGL: Failed to find GDI32");
 			}
 		}
 	}
