@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -164,7 +164,7 @@ QString ChanACL::permName(Perm p) {
 		case None:
 			return tr("None");
 		case Write:
-			return tr("Write");
+			return tr("Write ACL");
 		case Traverse:
 			return tr("Traverse");
 		case Enter:
