@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -38,7 +38,9 @@ class Group;
 class ChanACL;
 
 class Channel : public QObject {
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(Channel)
 	private:
 		QSet<Channel *> qsUnseen;
 	public:
@@ -64,8 +66,6 @@ class Channel : public QObject {
 		Channel(int id, QString name, QObject *p = NULL);
 		~Channel();
 
-		static bool validateName(const QString &qsName);
-
 		static Channel *get(int);
 		static Channel *add(int, QString, QObject *p = NULL);
 		static void remove(Channel *);
