@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -36,6 +36,8 @@
 class Channel;
 
 class Player {
+	private:
+		Q_DISABLE_COPY(Player)
 	public:
 		enum State { Connected, Authenticated };
 		State sState;
@@ -48,14 +50,15 @@ class Player {
 		bool bTalking, bAltSpeak;
 		Channel *cChannel;
 		QString getFlagsString() const;
-		static bool validateName(const QString &qsName);
 
 		Player();
 		virtual ~Player() {};
 };
 
 class ClientPlayer : public QObject, public Player {
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(ClientPlayer)
 	public:
 		ClientPlayer(QObject *p = NULL);
 		static QHash<unsigned int, ClientPlayer *> c_qmPlayers;
