@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -37,7 +37,13 @@
 #include "ui_AudioOutput.h"
 
 class AudioInputDialog : public ConfigWidget, public Ui::AudioInput {
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(AudioInputDialog)
+	protected:
+		QTimer *qtTick;
+		void hideEvent(QHideEvent *event);
+		void showEvent(QShowEvent *event);
 	public:
 		AudioInputDialog(Settings &st);
 		virtual QString title() const;
@@ -53,12 +59,16 @@ class AudioInputDialog : public ConfigWidget, public Ui::AudioInput {
 		void on_qsAmp_valueChanged(int v);
 		void on_qsDoublePush_valueChanged(int v);
 		void on_qsNoise_valueChanged(int v);
+		void on_qsIdle_valueChanged(int v);
 		void on_qcbTransmit_currentIndexChanged(int v);
 		void on_qcbSystem_currentIndexChanged(int);
+		void on_Tick_timeout();
 };
 
 class AudioOutputDialog : public ConfigWidget, public Ui::AudioOutput {
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(AudioOutputDialog)
 	public:
 		AudioOutputDialog(Settings &st);
 		virtual QString title() const;
@@ -70,6 +80,7 @@ class AudioOutputDialog : public ConfigWidget, public Ui::AudioOutput {
 		void on_qsDelay_valueChanged(int v);
 		void on_qsJitter_valueChanged(int v);
 		void on_qsVolume_valueChanged(int v);
+		void on_qsOtherVolume_valueChanged(int v);
 		void on_qsPacketDelay_valueChanged(int v);
 		void on_qsPacketLoss_valueChanged(int v);
 		void on_qcbLoopback_currentIndexChanged(int v);
