@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -73,8 +73,8 @@ AudioInputPtr AudioInputRegistrar::newFromChoice(QString choice) {
 
 	AudioInputRegistrar *r = NULL;
 	foreach(AudioInputRegistrar *air, *qmNew)
-	if (!r || (air->priority > r->priority))
-		r = air;
+		if (!r || (air->priority > r->priority))
+			r = air;
 	if (r) {
 		current = r->name;
 		return AudioInputPtr(r->create());
@@ -146,6 +146,7 @@ AudioInput::AudioInput() {
 
 	bRunning = false;
 
+	connect(this, SIGNAL(doMute()), g.mw->qaAudioMute, SLOT(trigger()), Qt::QueuedConnection);
 }
 
 AudioInput::~AudioInput() {
@@ -649,9 +650,7 @@ void AudioInput::encodeAudioFrame() {
 
 	iIsSpeech = iIsSpeech || (g.iPushToTalk > 0) || (g.iAltSpeak > 0);
 
-	if (
-	    ((g.s.lmLoopMode != Settings::Local) && (g.s.bMute || (p && p->bMute)))
-	    || g.bPushToMute) {
+	if (g.s.bMute || ((g.s.lmLoopMode != Settings::Local) && p && p->bMute) || g.bPushToMute) {
 		iIsSpeech = 0;
 	}
 
@@ -675,11 +674,17 @@ void AudioInput::encodeAudioFrame() {
 	}
 	if (! iIsSpeech && ! bPreviousVoice) {
 		iBitrate = 0;
+		if (g.s.iIdleTime && ! g.s.bMute && ((tIdle.elapsed() / 1000000ULL) > g.s.iIdleTime)) {
+			emit doMute();
+			tIdle.restart();
+		}
 		return;
 	}
 
 	bPreviousVoice = iIsSpeech;
 
+	tIdle.restart();
+
 	if (! iIsSpeech) {
 		memset(psMic, 0, sizeof(short) * iFrameSize);
 	}
