@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -33,12 +33,15 @@
 
 #include "Audio.h"
 #include "Settings.h"
+#include "Timer.h"
 #include "smallft.h"
 
 class AudioInput;
 typedef boost::shared_ptr<AudioInput> AudioInputPtr;
 
 class AudioInputRegistrar {
+	private:
+		Q_DISABLE_COPY(AudioInputRegistrar)
 	public:
 		static QMap<QString, AudioInputRegistrar *> *qmNew;
 		static QString current;
@@ -52,15 +55,18 @@ class AudioInputRegistrar {
 		virtual AudioInput *create() = 0;
 		virtual const QList<audioDevice> getDeviceChoices() = 0;
 		virtual void setDeviceChoice(const QVariant &, Settings &) = 0;
-		virtual bool canEcho(const QString &outputsys) = 0;
+		virtual bool canEcho(const QString &outputsys) const = 0;
 };
 
 class AudioInput : public QThread {
 		friend class AudioNoiseWidget;
 		friend class AudioEchoWidget;
 		friend class AudioStats;
+		friend class AudioInputDialog;
 		friend class FMODSystem;
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(AudioInput)
 	protected:
 		typedef enum { SampleShort, SampleFloat } SampleFormat;
 		typedef void (*inMixerFunc)(float * RESTRICT, const void * RESTRICT, unsigned int, unsigned int);
@@ -97,6 +103,8 @@ class AudioInput : public QThread {
 		float *pfEchoInput;
 		float *pfOutput;
 
+		Timer tIdle;
+
 		void encodeAudioFrame();
 		void addMic(const void *data, unsigned int nsamp);
 		void addEcho(const void *data, unsigned int nsamp);
@@ -113,6 +121,8 @@ class AudioInput : public QThread {
 		void flushCheck();
 
 		void initializeMixer();
+	signals:
+		void doMute();
 	public:
 		bool bResetProcessor;
 
