@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -70,8 +70,8 @@ AudioOutputPtr AudioOutputRegistrar::newFromChoice(QString choice) {
 
 	AudioOutputRegistrar *r = NULL;
 	foreach(AudioOutputRegistrar *aor, *qmNew)
-	if (!r || (aor->priority > r->priority))
-		r = aor;
+		if (!r || (aor->priority > r->priority))
+			r = aor;
 	if (r) {
 		current = r->name;
 		return AudioOutputPtr(r->create());
@@ -79,6 +79,14 @@ AudioOutputPtr AudioOutputRegistrar::newFromChoice(QString choice) {
 	return AudioOutputPtr();
 }
 
+bool AudioOutputRegistrar::canMuteOthers() const {
+	return false;
+}
+
+bool AudioOutputRegistrar::usesOutputDelay() const {
+	return true;
+}
+
 AudioOutputPlayer::AudioOutputPlayer(const QString name) : qsName(name) {
 	iBufferSize = 0;
 	pfBuffer = NULL;
@@ -321,7 +329,7 @@ float AudioOutput::calcGain(float dotproduct, float distance) {
 
 void AudioOutput::wipe() {
 	foreach(AudioOutputPlayer *aop, qmOutputs)
-	removeBuffer(aop);
+		removeBuffer(aop);
 }
 
 const float *AudioOutput::getSpeakerPos(unsigned int &speakers) {
@@ -532,7 +540,7 @@ bool AudioOutput::mix(void *outbuff, unsigned int nsamp) {
 		for (unsigned int i=0;i<iChannels;++i)
 			svol[i] = mul * fSpeakerVolume[i];
 
-		if (g.s.bPositionalAudio && (iChannels > 1) && g.p->fetch()) {
+		if (g.s.bPositionalAudio && (iChannels > 1) && g.p->fetch() && (g.bPosTest || g.p->fPosition[0] != 0 || g.p->fPosition[1] != 0 || g.p->fPosition[2] != 0)) {
 			float front[3] = { g.p->fFront[0], g.p->fFront[1], g.p->fFront[2] };
 			float top[3] = { g.p->fTop[0], g.p->fTop[1], g.p->fTop[2] };
 
@@ -577,21 +585,16 @@ bool AudioOutput::mix(void *outbuff, unsigned int nsamp) {
 			validListener = true;
 		}
 		foreach(aop, qlMix) {
-
-#ifdef AUDIO_TEST
-			aop->fPos[0] = 4.0f;
-			aop->fPos[1] = 0.0f;
-			aop->fPos[2] = 0.0f;
-#endif
-
 			const float * RESTRICT pfBuffer = aop->pfBuffer;
 
 			if (validListener && ((aop->fPos[0] != 0.0f) || (aop->fPos[1] != 0.0f) || (aop->fPos[2] != 0.0f))) {
 				float dir[3] = { aop->fPos[0] - g.p->fPosition[0], aop->fPos[1] - g.p->fPosition[1], aop->fPos[2] - g.p->fPosition[2] };
 				float len = sqrtf(dir[0] * dir[0] + dir[1] * dir[1] + dir[2] * dir[2]);
-				dir[0] /= len;
-				dir[1] /= len;
-				dir[2] /= len;
+				if (len > 0.0f) {
+					dir[0] /= len;
+					dir[1] /= len;
+					dir[2] /= len;
+				}
 				/*
 								qWarning("Voice pos: %f %f %f", aop->fPos[0], aop->fPos[1], aop->fPos[2]);
 								qWarning("Voice dir: %f %f %f", dir[0], dir[1], dir[2]);
@@ -624,23 +627,18 @@ bool AudioOutput::mix(void *outbuff, unsigned int nsamp) {
 			}
 		}
 		// Clip
-		if (qlMix.count() > 1) {
-			if (eSampleFormat == SampleFloat)
-				for (unsigned int i=0;i<nsamp*iChannels;i++)
-					output[i] = output[i] < -1.0f ? -1.0f : (output[i] > 1.0f ? 1.0f : output[i]);
-			else
-				for (unsigned int i=0;i<nsamp*iChannels;i++)
-					reinterpret_cast<short *>(outbuff)[i] = static_cast<short>(32768.f * (output[i] < -1.0f ? -1.0f : (output[i] > 1.0f ? 1.0f : output[i])));
-		} else if (eSampleFormat == SampleShort) {
+		if (eSampleFormat == SampleFloat)
 			for (unsigned int i=0;i<nsamp*iChannels;i++)
-				reinterpret_cast<short *>(outbuff)[i] = static_cast<short>(32768.f * output[i]);
-		}
+				output[i] = output[i] < -1.0f ? -1.0f : (output[i] > 1.0f ? 1.0f : output[i]);
+		else
+			for (unsigned int i=0;i<nsamp*iChannels;i++)
+				reinterpret_cast<short *>(outbuff)[i] = static_cast<short>(32768.f * (output[i] < -1.0f ? -1.0f : (output[i] > 1.0f ? 1.0f : output[i])));
 	}
 
 	qrwlOutputs.unlock();
 
 	foreach(aop, qlDel)
-	removeBuffer(aop);
+		removeBuffer(aop);
 
 	return (! qlMix.isEmpty());
 }
