@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -68,6 +68,8 @@ class ClientPlayer;
 typedef boost::shared_ptr<AudioOutput> AudioOutputPtr;
 
 class AudioOutputRegistrar {
+	private:
+		Q_DISABLE_COPY(AudioOutputRegistrar)
 	public:
 		static QMap<QString, AudioOutputRegistrar *> *qmNew;
 		static QString current;
@@ -81,11 +83,15 @@ class AudioOutputRegistrar {
 		virtual AudioOutput *create() = 0;
 		virtual const QList<audioDevice> getDeviceChoices() = 0;
 		virtual void setDeviceChoice(const QVariant &, Settings &) = 0;
+		virtual bool canMuteOthers() const;
+		virtual bool usesOutputDelay() const;
 };
 
 class AudioOutputPlayer : public QObject {
 		friend class AudioOutput;
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(AudioOutputPlayer)
 	protected:
 		unsigned int iBufferSize;
 		void resizeBuffer(unsigned int newsize);
@@ -101,7 +107,9 @@ class AudioOutputPlayer : public QObject {
 
 class AudioOutputSpeech : public AudioOutputPlayer {
 		friend class AudioOutput;
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(AudioOutputSpeech)
 	protected:
 		unsigned int iBufferOffset;
 		unsigned int iBufferFilled;
@@ -133,7 +141,9 @@ class AudioOutputSpeech : public AudioOutputPlayer {
 };
 
 class AudioSine : public AudioOutputPlayer {
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(AudioSine)
 	protected:
 		float v;
 		float inc;
@@ -150,7 +160,9 @@ class AudioSine : public AudioOutputPlayer {
 };
 
 class AudioOutput : public QThread {
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(AudioOutput)
 	private:
 		float *fSpeakers;
 		float *fSpeakerVolume;
