@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -34,9 +34,22 @@
 #include "Settings.h"
 #include "AudioStats.h"
 #include "AudioOutput.h"
+#include "GlobalShortcut.h"
+
+class CompletablePage : public QWizardPage {
+		Q_OBJECT
+	protected:
+		bool bComplete;
+	public:
+		CompletablePage(QWizard *p = NULL);
+		void setComplete(bool);
+		bool isComplete() const;
+};
 
 class AudioWizard: public QWizard {
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(AudioWizard)
 	protected:
 		QComboBox *qcbInput, *qcbInputDevice;
 		QComboBox *qcbOutput, *qcbOutputDevice;
@@ -49,9 +62,12 @@ class AudioWizard: public QWizard {
 		AudioBar *abAmplify;
 		QSlider *qsMaxAmp;
 
+		QWidget *qwVAD;
 		AudioBar *abVAD;
-		QRadioButton *qrAmplitude, *qrSNR;
+		QRadioButton *qrAmplitude, *qrSNR, *qrPTT;
 		QSlider *qsMinVAD, *qsMaxVAD;
+		ShortcutKeyWidget *skwPTT;
+		bool bTransmitChanged;
 
 		QSlider *qsHoldtime;
 		QLabel *qlHoldtime;
@@ -66,15 +82,17 @@ class AudioWizard: public QWizard {
 		float fAngle;
 		float fX, fY;
 
-		QWizardPage *qwpIntro, *qwpDevice, *qwpVolume, *qwpTrigger, *qwpDeviceTuning, *qwpPositional, *qwpDone;
+		QCheckBox *qcbUsage;
 
-		QWizardPage *introPage();
-		QWizardPage *devicePage();
-		QWizardPage *volumePage();
-		QWizardPage *triggerPage();
-		QWizardPage *deviceTuningPage();
-		QWizardPage *positionalPage();
-		QWizardPage *donePage();
+		CompletablePage *qwpIntro, *qwpDevice, *qwpVolume, *qwpTrigger, *qwpDeviceTuning, *qwpPositional, *qwpDone;
+
+		CompletablePage *introPage();
+		CompletablePage *devicePage();
+		CompletablePage *volumePage();
+		CompletablePage *triggerPage();
+		CompletablePage *deviceTuningPage();
+		CompletablePage *positionalPage();
+		CompletablePage *donePage();
 
 		Settings sOldSettings;
 
@@ -82,6 +100,8 @@ class AudioWizard: public QWizard {
 
 		bool bInit;
 
+		bool bDelay;
+
 		int iMaxPeak;
 		int iTicks;
 
@@ -102,10 +122,13 @@ class AudioWizard: public QWizard {
 		void on_Holdtime_valueChanged(int);
 		void on_Amplitude_clicked(bool);
 		void on_SNR_clicked(bool);
+		void on_PTT_clicked(bool);
 		void on_Echo_clicked(bool);
 		void on_Headphone_clicked(bool);
 		void on_Positional_clicked(bool);
+		void on_PTTKey_keySet(bool);
 		void showPage(int);
+		void updateTriggerWidgets(bool);
 	public:
 		AudioWizard(QWidget *parent);
 		void reject();
