@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -49,7 +49,9 @@ class TextSortedItem : public QTreeWidgetItem {
 };
 
 class ConnectDialog : public QDialog, public Ui::ConnectDialog {
-		Q_OBJECT;
+	private:
+		Q_OBJECT
+		Q_DISABLE_COPY(ConnectDialog)
 	protected:
 		static QList<PublicInfo> qlPublicServers;
 		static Timer tPublicServers;
