@@ -1,5 +1,5 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
-   Copyright (C) 2008, Mikkel Krautz <mikkel@krautz.dk>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
+   Copyright (C) 2008-2009, Mikkel Krautz <mikkel@krautz.dk>
 
    All rights reserved.
 
@@ -39,6 +39,9 @@
  * properly set up to receieve global keyboard/mouse events.
  */
 
+GlobalShortcutMacInit::GlobalShortcutMacInit() : QObject(NULL) {
+}
+
 void GlobalShortcutMacInit::initialize() {
 	if (!accessibilityApiEnabled())
 		accessibilityDialog();
@@ -80,6 +83,7 @@ CGEventRef EventTapCallback(CGEventTapProxy proxy, CGEventType type,
 	unsigned int keycode;
 	bool suppress = false;
 	bool down = false;
+	int64_t repeat = 0;
 
 	switch (type) {
 		case kCGEventLeftMouseDown:
@@ -99,7 +103,7 @@ CGEventRef EventTapCallback(CGEventTapProxy proxy, CGEventType type,
 		case kCGEventKeyDown:
 			down = true;
 		case kCGEventKeyUp:
-			int64_t repeat = CGEventGetIntegerValueField(event, kCGKeyboardEventAutorepeat);
+			repeat = CGEventGetIntegerValueField(event, kCGKeyboardEventAutorepeat);
 			if (! repeat) {
 				keycode = static_cast<unsigned int>(CGEventGetIntegerValueField(event, kCGKeyboardEventKeycode));
 				suppress = gs->handleButton(keycode, down);
