@@ -1,5 +1,5 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
-   Copyright (C) 2008, Mikkel Krautz <mikkel@krautz.dk>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
+   Copyright (C) 2008-2009, Mikkel Krautz <mikkel@krautz.dk>
 
    All rights reserved.
 
@@ -38,8 +38,11 @@
 #include "Global.h"
 
 class GlobalShortcutMacInit : public QObject, public DeferInit {
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(GlobalShortcutMacInit)
 	public:
+		GlobalShortcutMacInit();
 		void initialize();
 	public slots:
 		void openPrefsPane(const QString &) const;
@@ -49,8 +52,9 @@ class GlobalShortcutMacInit : public QObject, public DeferInit {
 };
 
 class GlobalShortcutMac : public GlobalShortcutEngine {
+	private:
 		Q_OBJECT
-
+		Q_DISABLE_COPY(GlobalShortcutMac)
 	public:
 		GlobalShortcutMac();
 		~GlobalShortcutMac();
