@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -49,25 +49,50 @@ GlobalShortcutEngine *GlobalShortcutEngine::platformInit() {
 }
 
 GlobalShortcutWin::GlobalShortcutWin() {
-	timer = new QTimer(this);
-	connect(timer, SIGNAL(timeout()), this, SLOT(timeTicked()));
-
-	HRESULT hr;
-
 	pDI = NULL;
+	moveToThread(this);
+	start(QThread::LowestPriority);
+}
+
+GlobalShortcutWin::~GlobalShortcutWin() {
+	quit();
+	wait();
+}
+
+void GlobalShortcutWin::run() {
+	HMODULE hSelf;
+	HRESULT hr;
+	QTimer *timer;
 
 	if (FAILED(hr = DirectInput8Create(GetModuleHandle(NULL), DIRECTINPUT_VERSION, IID_IDirectInput8, reinterpret_cast<void **>(&pDI), NULL))) {
 		qFatal("GlobalShortcutWin: Failed to create d8input");
 		return;
 	}
 
+	/*
+	 * Wait for MainWindow's constructor to finish before we enumerate DirectInput devices.
+	 * We need to do this because adding a new device requires a Window handle. (SetCooperativeLevel())
+	 */
+	while (! g.mw)
+		this->msleep(20);
+
+	pDI->EnumDevices(DI8DEVCLASS_ALL, EnumDevicesCB, static_cast<void *>(this), DIEDFL_ALLDEVICES);
+
+	GetModuleHandleEx(GET_MODULE_HANDLE_EX_FLAG_FROM_ADDRESS | GET_MODULE_HANDLE_EX_FLAG_UNCHANGED_REFCOUNT, (wchar_t *) &HookKeyboard, &hSelf);
+	hhKeyboard = SetWindowsHookEx(WH_KEYBOARD_LL, HookKeyboard, hSelf, 0);
+	hhMouse = SetWindowsHookEx(WH_MOUSE_LL, HookMouse, hSelf, 0);
+
+	timer = new QTimer(this);
+	connect(timer, SIGNAL(timeout()), this, SLOT(timeTicked()));
 	timer->start(20);
-	start(QThread::TimeCriticalPriority);
-}
+
+	setPriority(QThread::TimeCriticalPriority);
+
+	exec();
+
+	UnhookWindowsHookEx(hhKeyboard);
+	UnhookWindowsHookEx(hhMouse);
 
-GlobalShortcutWin::~GlobalShortcutWin() {
-	quit();
-	wait();
 	foreach(InputDevice *id, qhInputDevices) {
 		if (id->pDID) {
 			id->pDID->Unacquire();
@@ -77,18 +102,6 @@ GlobalShortcutWin::~GlobalShortcutWin() {
 	pDI->Release();
 }
 
-void GlobalShortcutWin::run() {
-	HMODULE hSelf;
-	GetModuleHandleEx(GET_MODULE_HANDLE_EX_FLAG_FROM_ADDRESS | GET_MODULE_HANDLE_EX_FLAG_UNCHANGED_REFCOUNT, (wchar_t *) &HookKeyboard, &hSelf);
-	hhKeyboard = SetWindowsHookEx(WH_KEYBOARD_LL, HookKeyboard, hSelf, 0);
-	hhMouse = SetWindowsHookEx(WH_MOUSE_LL, HookMouse, hSelf, 0);
-
-	exec();
-
-	UnhookWindowsHookEx(hhKeyboard);
-	UnhookWindowsHookEx(hhMouse);
-}
-
 LRESULT CALLBACK GlobalShortcutWin::HookKeyboard(int nCode, WPARAM wParam, LPARAM lParam) {
 	GlobalShortcutWin *gsw=static_cast<GlobalShortcutWin *>(engine);
 	KBDLLHOOKSTRUCT *key=reinterpret_cast<KBDLLHOOKSTRUCT *>(lParam);
@@ -142,8 +155,6 @@ LRESULT CALLBACK GlobalShortcutWin::HookMouse(int nCode, WPARAM wParam, LPARAM l
 	return CallNextHookEx(gsw->hhMouse, nCode, wParam, lParam);
 }
 
-
-
 BOOL CALLBACK GlobalShortcutWin::EnumDeviceObjectsCallback(LPCDIDEVICEOBJECTINSTANCE lpddoi, LPVOID pvRef) {
 	InputDevice *id=static_cast<InputDevice *>(pvRef);
 	QString name = QString::fromUtf16(reinterpret_cast<const ushort *>(lpddoi->tszName));
@@ -226,9 +237,6 @@ void GlobalShortcutWin::timeTicked() {
 	if (bNeedRemap)
 		remap();
 
-	if (qhInputDevices.isEmpty())
-		pDI->EnumDevices(DI8DEVCLASS_ALL, EnumDevicesCB, static_cast<void *>(this), DIEDFL_ALLDEVICES);
-
 	foreach(InputDevice *id, qhInputDevices) {
 		DIDEVICEOBJECTDATA rgdod[DX_SAMPLE_BUFFER_SIZE];
 		DWORD   dwItems = DX_SAMPLE_BUFFER_SIZE;
