@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -60,7 +60,7 @@ LogTitleBar::LogTitleBar() {
 	qtTick = new QTimer(this);
 	qtTick->setSingleShot(true);
 	connect(qtTick, SIGNAL(timeout()), this, SLOT(tick()));
-	size = newsize = 1;
+	size = newsize = 0;
 }
 
 QSize LogTitleBar::sizeHint() const {
@@ -108,7 +108,10 @@ void LogTitleBar::tick() {
 }
 
 MainWindow::MainWindow(QWidget *p) : QMainWindow(p) {
-
+	qiIconMute.addFile(QLatin1String("skin:muted_self.png"));
+	qiIconMute.addFile(QLatin1String("skin:muted_overlay.png"));
+	qiIconDeaf.addFile(QLatin1String("skin:deafened_self.png"));
+	qiIconDeaf.addFile(QLatin1String("skin:deafened_overlay.png"));
 	qiIcon.addFile(QLatin1String("skin:mumble.16x16.png"));
 	qiIcon.addFile(QLatin1String("skin:mumble.32x32.png"));
 	qiIcon.addFile(QLatin1String("skin:mumble.64x64.png"));
@@ -143,25 +146,11 @@ MainWindow::MainWindow(QWidget *p) : QMainWindow(p) {
 	// Fix context of all actions.
 	QList<QAction *> qla = findChildren<QAction *>();
 	foreach(QAction *a, qla)
-	a->setShortcutContext(Qt::ApplicationShortcut);
+		a->setShortcutContext(Qt::ApplicationShortcut);
 
 	setOnTop(g.s.bAlwaysOnTop);
 }
 
-void MainWindow::setOnTop(bool top) {
-	Qt::WindowFlags wf = windowFlags();
-	if (wf.testFlag(Qt::WindowStaysOnTopHint) != top) {
-		if (top)
-			wf |= Qt::WindowStaysOnTopHint;
-		else
-			wf &= ~Qt::WindowStaysOnTopHint;
-		bNoHide = true;
-		setWindowFlags(wf);
-		show();
-		bNoHide = false;
-	}
-}
-
 void MainWindow::createActions() {
 	int idx = 1;
 	gsPushTalk=new GlobalShortcut(this, idx++, tr("Push-to-Talk", "Global Shortcut"));
@@ -223,6 +212,11 @@ void MainWindow::createActions() {
 	qstiIcon = new QSystemTrayIcon(qiIcon, this);
 	qstiIcon->setToolTip(tr("Mumble"));
 	qstiIcon->setObjectName(QLatin1String("Icon"));
+
+	qmTray = new QMenu(this);
+	qmTray->addAction(tr("&Quit"), this, SLOT(on_qaQuit_triggered()));
+	qstiIcon->setContextMenu(qmTray);
+	updateTrayIcon();
 #ifndef Q_OS_MAC
 	qstiIcon->show();
 #endif
@@ -256,6 +250,7 @@ void MainWindow::setupGui()  {
 	qaHelpWhatsThis->setShortcuts(QKeySequence::WhatsThis);
 
 	qaConfigMinimal->setChecked(g.s.bMinimalView);
+	qaConfigHideFrame->setChecked(g.s.bHideFrame);
 
 	connect(gsResetAudio, SIGNAL(down()), qaAudioReset, SLOT(trigger()));
 	connect(gsMuteSelf, SIGNAL(down()), qaAudioMute, SLOT(trigger()));
@@ -271,11 +266,15 @@ void MainWindow::setupGui()  {
 		w->setMouseTracking(true);
 	}
 
-	restoreGeometry(g.s.qbaMainWindowGeometry);
+	if (g.s.bMinimalView && ! g.s.qbaMinimalViewGeometry.isNull())
+		restoreGeometry(g.s.qbaMinimalViewGeometry);
+	else if (! g.s.bMinimalView && ! g.s.qbaMainWindowGeometry.isNull())
+		restoreGeometry(g.s.qbaMainWindowGeometry);
+
 	restoreState(g.s.qbaMainWindowState);
 	qtvPlayers->header()->restoreState(g.s.qbaHeaderState);
 
-	setupView();
+	setupView(false);
 }
 
 MainWindow::~MainWindow() {
@@ -304,9 +303,12 @@ void MainWindow::closeEvent(QCloseEvent *e) {
 	}
 #endif
 	g.uiSession = 0;
-	g.s.qbaMainWindowGeometry = saveGeometry();
+
 	g.s.qbaMainWindowState = saveState();
-	if (! g.s.bMinimalView) {
+	if (g.s.bMinimalView) {
+		g.s.qbaMinimalViewGeometry = saveGeometry();
+	} else {
+		g.s.qbaMainWindowGeometry = saveGeometry();
 		g.s.qbaHeaderState = qtvPlayers->header()->saveState();
 	}
 	QMainWindow::closeEvent(e);
@@ -315,7 +317,7 @@ void MainWindow::closeEvent(QCloseEvent *e) {
 
 void MainWindow::hideEvent(QHideEvent *e) {
 #ifndef Q_OS_MAC
-	if (!bNoHide && qstiIcon->isSystemTrayAvailable())
+	if (g.s.bHideTray && !bNoHide && qstiIcon->isSystemTrayAvailable())
 		qApp->postEvent(this, new QEvent(static_cast<QEvent::Type>(TI_QEVENT)));
 	QMainWindow::hideEvent(e);
 #endif
@@ -334,6 +336,18 @@ void MainWindow::on_qtvPlayers_customContextMenuRequested(const QPoint &mpos) {
 	}
 }
 
+void MainWindow::updateTrayIcon() {
+	ClientPlayer *p=ClientPlayer::get(g.uiSession);
+
+	if (g.s.bDeaf || (p && p->bDeaf)) {
+		qstiIcon->setIcon(qiIconDeaf);
+	} else if (g.s.bMute || (p && p->bMute)) {
+		qstiIcon->setIcon(qiIconMute);
+	} else {
+		qstiIcon->setIcon(qiIcon);
+	}
+}
+
 void MainWindow::on_qtvPlayers_doubleClicked(const QModelIndex &idx) {
 	Player *p = pmModel->getPlayer(idx);
 	if (p) {
@@ -437,34 +451,68 @@ void MainWindow::findDesiredChannel() {
 	}
 }
 
-void MainWindow::setupView() {
+void MainWindow::setOnTop(bool top) {
+	Qt::WindowFlags wf = windowFlags();
+	if (wf.testFlag(Qt::WindowStaysOnTopHint) != top) {
+		if (top)
+			wf |= Qt::WindowStaysOnTopHint;
+		else
+			wf &= ~Qt::WindowStaysOnTopHint;
+		bNoHide = true;
+		setWindowFlags(wf);
+		show();
+		bNoHide = false;
+	}
+}
+
+void MainWindow::setupView(bool toggle_minimize) {
 	bool showit = ! g.s.bMinimalView;
 
 	bNoHide = true;
+	QRect geom = frameGeometry();
 
-	if (! showit)
-		g.s.qbaMainWindowState = saveState();
-
-	qdwLog->setVisible(showit);
-
-	if (showit) {
-		restoreState(g.s.qbaMainWindowState);
-		qdwLog->setVisible(showit);
+	if (toggle_minimize) {
+		if (! showit) {
+			g.s.qbaMainWindowGeometry = saveGeometry();
+			g.s.qbaHeaderState = qtvPlayers->header()->saveState();
+		} else {
+			g.s.qbaMinimalViewGeometry = saveGeometry();
+		}
 	}
 
+	Qt::WindowFlags f = Qt::Window;
+	if (!showit && g.s.bHideFrame)
+		f = Qt::Window | Qt::FramelessWindowHint;
+#ifndef Q_OS_MAC
+	else if (!showit)
+		f = Qt::Tool;
+#endif
+
+	if (g.s.bAlwaysOnTop)
+		f |= Qt::WindowStaysOnTopHint;
 
-	Qt::WindowFlags f = windowFlags();
-	if (showit)
-		f = 0;
-	else
-		f = Qt::CustomizeWindowHint;
 	setWindowFlags(f);
-	show();
+
+	qdwLog->setVisible(showit);
 	qtvPlayers->header()->setVisible(showit);
 	menuBar()->setVisible(showit);
 
+	if (toggle_minimize) {
+		if (! showit && ! g.s.qbaMinimalViewGeometry.isNull())
+			restoreGeometry(g.s.qbaMinimalViewGeometry);
+		else if (showit && ! g.s.qbaMainWindowGeometry.isNull())
+			restoreGeometry(g.s.qbaMainWindowGeometry);
+	} else {
+		QRect newgeom = frameGeometry();
+		resize(geometry().width()-newgeom.width()+geom.width(),
+		       geometry().height()-newgeom.height()+geom.height());
+		move(geom.x(), geom.y());
+	}
 
+	show();
+	activateWindow();
 	bNoHide = false;
+
 }
 
 void MainWindow::on_qaServerConnect_triggered() {
@@ -708,6 +756,18 @@ void MainWindow::on_qaQuit_triggered() {
 	this->close();
 }
 
+void MainWindow::on_qmConfig_aboutToShow() {
+	// Don't remove the config, as that messes up OSX.
+	foreach(QAction *a, qmConfig->actions())
+		if (a != qaConfigDialog)
+			qmConfig->removeAction(a);
+	qmConfig->addAction(qaAudioWizard);
+	qmConfig->addSeparator();
+	qmConfig->addAction(qaConfigMinimal);
+	if (g.s.bMinimalView)
+		qmConfig->addAction(qaConfigHideFrame);
+}
+
 void MainWindow::on_qmChannel_aboutToShow() {
 	QModelIndex idx = qtvPlayers->currentIndex();
 
@@ -957,6 +1017,8 @@ void MainWindow::on_qaAudioMute_triggered() {
 	mpsmd.bMute = g.s.bMute;
 	mpsmd.bDeaf = g.s.bDeaf;
 	g.sh->sendMessage(&mpsmd);
+
+	updateTrayIcon();
 }
 
 void MainWindow::on_qaAudioDeaf_triggered() {
@@ -975,6 +1037,8 @@ void MainWindow::on_qaAudioDeaf_triggered() {
 	mpsmd.bMute = g.s.bMute;
 	mpsmd.bDeaf = g.s.bDeaf;
 	g.sh->sendMessage(&mpsmd);
+
+	updateTrayIcon();
 }
 
 void MainWindow::on_qaAudioTTS_triggered() {
@@ -1001,6 +1065,11 @@ void MainWindow::on_qaConfigMinimal_triggered() {
 	setupView();
 }
 
+void MainWindow::on_qaConfigHideFrame_triggered() {
+	g.s.bHideFrame = qaConfigHideFrame->isChecked();
+	setupView(false);
+}
+
 void MainWindow::on_qaAudioWizard_triggered() {
 	AudioWizard *aw = new AudioWizard(this);
 	aw->exec();
@@ -1067,7 +1136,7 @@ void MainWindow::on_CenterPos_triggered(bool down) {
 void MainWindow::on_VolumeUp_triggered(bool down) {
 	if (down) {
 		float v = floorf(g.s.fVolume * 10.0f);
-		if (v < 10.0f)
+		if (v < 20.0f)
 			g.s.fVolume = ++v / 10.0f;
 	}
 }
@@ -1129,7 +1198,7 @@ void MainWindow::pushLink(bool down) {
 			mcl.ltType = MessageChannelLink::PushUnlink;
 		if (idx == 10) {
 			foreach(Channel *l, home->qlChannels)
-			mcl.qlTargets << l->iId;
+				mcl.qlTargets << l->iId;
 		} else if (target) {
 			mcl.qlTargets << target->iId;
 		}
@@ -1173,6 +1242,7 @@ void MainWindow::serverDisconnected(QString reason) {
 	qaServerDisconnect->setEnabled(false);
 	qaServerInformation->setEnabled(false);
 	qaServerBanList->setEnabled(false);
+	updateTrayIcon();
 
 	QString uname, pw, host;
 	unsigned short port;
@@ -1195,7 +1265,7 @@ void MainWindow::serverDisconnected(QString reason) {
 
 	if (! g.sh->qlErrors.isEmpty()) {
 		foreach(QSslError e, g.sh->qlErrors)
-		g.l->log(Log::ServerDisconnected, tr("SSL Verification failed: %1").arg(e.errorString()));
+			g.l->log(Log::ServerDisconnected, tr("SSL Verification failed: %1").arg(e.errorString()));
 		if (! g.sh->qscCert.isEmpty()) {
 			QSslCertificate c = g.sh->qscCert.at(0);
 			QString basereason;
@@ -1206,7 +1276,7 @@ void MainWindow::serverDisconnected(QString reason) {
 			}
 			QStringList qsl;
 			foreach(QSslError e, g.sh->qlErrors)
-			qsl << QString::fromLatin1("<li>%1</li>").arg(e.errorString());
+				qsl << QString::fromLatin1("<li>%1</li>").arg(e.errorString());
 
 			QMessageBox qmb(QMessageBox::Warning, tr("Mumble"),
 			                tr("<p>%1.<br />The specific errors with this certificate are: </p><ol>%2</ol>"
@@ -1242,16 +1312,22 @@ void MainWindow::serverDisconnected(QString reason) {
 			g.l->log(Log::ServerDisconnected, tr("Disconnected from server."));
 		}
 
+
+		Qt::WindowFlags wf = 0;
+#ifdef Q_OS_MAC
+		wf = Qt::Sheet;
+#endif
+
 		switch (rtLast) {
 			case MessageServerReject::InvalidUsername:
 			case MessageServerReject::UsernameInUse:
 				matched = true;
-				uname = QInputDialog::getText(this, tr("Invalid username"), (rtLast == MessageServerReject::InvalidUsername) ? tr("You connected with an invalid username, please try another one.") : tr("That username is already in use, please try another username."), QLineEdit::Normal, uname, &ok);
+				uname = QInputDialog::getText(this, tr("Invalid username"), (rtLast == MessageServerReject::InvalidUsername) ? tr("You connected with an invalid username, please try another one.") : tr("That username is already in use, please try another username."), QLineEdit::Normal, uname, &ok, wf);
 				break;
 			case MessageServerReject::WrongUserPW:
 			case MessageServerReject::WrongServerPW:
 				matched = true;
-				pw = QInputDialog::getText(this, tr("Wrong password"), (rtLast == MessageServerReject::WrongUserPW) ? tr("Wrong password for registered users, please try again.") : tr("Wrong server password for unregistered user account, please try again."), QLineEdit::Password, pw, &ok);
+				pw = QInputDialog::getText(this, tr("Wrong password"), (rtLast == MessageServerReject::WrongUserPW) ? tr("Wrong password for registered users, please try again.") : tr("Wrong server password for unregistered user account, please try again."), QLineEdit::Password, pw, &ok, wf);
 				break;
 			default:
 				break;
@@ -1267,13 +1343,15 @@ void MainWindow::serverDisconnected(QString reason) {
 	}
 }
 
-void MainWindow::on_Icon_activated(QSystemTrayIcon::ActivationReason) {
-	if (! isVisible()) {
-		show();
-		showNormal();
-		activateWindow();
-	} else {
-		hide();
+void MainWindow::on_Icon_activated(QSystemTrayIcon::ActivationReason reason) {
+	if (reason == QSystemTrayIcon::Trigger) {
+		if (! isVisible()) {
+			show();
+			showNormal();
+			activateWindow();
+		} else {
+			hide();
+		}
 	}
 }
 
