@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -433,7 +433,7 @@ void Overlay::fixFont() {
 
 void Overlay::clearCache() {
 	foreach(unsigned char *ptr, qhTextures)
-	delete [] ptr;
+		delete [] ptr;
 
 	qhTextures.clear();
 	qhWidths.clear();
@@ -529,7 +529,7 @@ void Overlay::setTexts(const QList<TextLine> &lines) {
 					width += TEXT_HEIGHT;
 
 				te->width = static_cast<short>(width);
-				te->bUpdated = true;
+				te->uiCounter++;
 			}
 			qsForce.remove(tl.iPlayer);
 		}
