@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -36,6 +36,7 @@
 #include "Player.h"
 #include "Global.h"
 #include "Overlay.h"
+#include "LCD.h"
 #include "Log.h"
 
 QHash <Channel *, ModelItem *> ModelItem::c_qhChannels;
@@ -515,6 +516,7 @@ ModelItem *PlayerModel::moveItem(ModelItem *oldparent, ModelItem *newparent, Mod
 		v->setCurrentIndex(QModelIndex());
 	}
 
+	bool expanded = v->isExpanded(index(item));
 
 	if (newparent == oldparent) {
 		// Mangle rows. newrow needs to be pre-remove. oldrow needs to be postremove.
@@ -538,6 +540,7 @@ ModelItem *PlayerModel::moveItem(ModelItem *oldparent, ModelItem *newparent, Mod
 
 	endInsertRows();
 
+
 	QModelIndexList from, to;
 	from << createIndex(oldrow, 0, item);
 	from << createIndex(oldrow, 1, item);
@@ -558,6 +561,8 @@ ModelItem *PlayerModel::moveItem(ModelItem *oldparent, ModelItem *newparent, Mod
 	if (active.isValid()) {
 		sel->select(active, QItemSelectionModel::SelectCurrent);
 	}
+	if (expanded)
+		v->expand(index(t));
 	return t;
 }
 
@@ -589,7 +594,7 @@ void PlayerModel::ensureSelfVisible() {
 	if (! g.uiSession)
 		return;
 
-	expandAll(ClientPlayer::get(g.uiSession)->cChannel);
+	g.mw->qtvPlayers->scrollTo(index(ClientPlayer::get(g.uiSession)));
 }
 
 void PlayerModel::recheckLinks() {
@@ -666,9 +671,6 @@ void PlayerModel::removePlayer(ClientPlayer *p) {
 	citem->qlChildren.removeAt(row);
 	endRemoveRows();
 
-	if (g.uiSession && (p->cChannel == ClientPlayer::get(g.uiSession)->cChannel))
-		updateOverlay();
-
 	p->cChannel = NULL;
 
 	ClientPlayer::remove(p);
@@ -682,6 +684,9 @@ void PlayerModel::removePlayer(ClientPlayer *p) {
 
 	if (g.s.ceExpand == Settings::ChannelsWithPlayers)
 		collapseEmpty(c);
+
+	if (g.uiSession && (p->cChannel == ClientPlayer::get(g.uiSession)->cChannel))
+		updateOverlay();
 }
 
 void PlayerModel::movePlayer(ClientPlayer *p, Channel *np) {
@@ -710,6 +715,12 @@ void PlayerModel::movePlayer(ClientPlayer *p, Channel *np) {
 		expandAll(np);
 		collapseEmpty(oc);
 	}
+
+	if (g.uiSession) {
+		Channel *home = ClientPlayer::get(g.uiSession)->cChannel;
+		if (home==np || home == oc)
+			updateOverlay();
+	}
 }
 
 void PlayerModel::renamePlayer(ClientPlayer *p, const QString &name) {
@@ -719,6 +730,9 @@ void PlayerModel::renamePlayer(ClientPlayer *p, const QString &name) {
 	ModelItem *pi = ModelItem::c_qhChannels.value(c);
 	ModelItem *item = ModelItem::c_qhPlayers.value(p);
 	moveItem(pi, pi, item);
+
+	if (g.uiSession && (p->cChannel == ClientPlayer::get(g.uiSession)->cChannel))
+		updateOverlay();
 }
 
 void PlayerModel::renameChannel(Channel *c, const QString &name) {
@@ -819,13 +833,13 @@ void PlayerModel::moveChannel(Channel *c, Channel *p) {
 
 void PlayerModel::linkChannels(Channel *c, QList<Channel *> links) {
 	foreach(Channel *l, links)
-	c->link(l);
+		c->link(l);
 	recheckLinks();
 }
 
 void PlayerModel::unlinkChannels(Channel *c, QList<Channel *> links) {
 	foreach(Channel *l, links)
-	c->unlink(l);
+		c->unlink(l);
 	recheckLinks();
 }
 
@@ -998,6 +1012,7 @@ bool PlayerModel::dropMimeData(const QMimeData *md, Qt::DropAction, int, int, co
 
 void PlayerModel::updateOverlay() const {
 	g.o->updateOverlay();
+	g.lcd->updatePlayerView();
 }
 
 PlayerDelegate::PlayerDelegate(QObject *p) : QItemDelegate(p) {
