@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -79,7 +79,7 @@ void ServerHandler::customEvent(QEvent *evt) {
 			if (shme->bFlush)
 				cConnection->forceFlush();
 		} else {
-			cConnection->disconnectSocket();
+			exit(0);
 		}
 	}
 }
@@ -194,6 +194,9 @@ void ServerHandler::run() {
 		qusUdp = NULL;
 	}
 
+	if (qtsSock->state() == QAbstractSocket::ConnectedState)
+		serverConnectionClosed(QString());
+
 	ticker->stop();
 	cConnection->disconnectSocket();
 	cConnection.reset();
