@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -49,7 +49,9 @@ class ServerHandlerMessageEvent : public QEvent {
 typedef boost::shared_ptr<Connection> ConnectionPtr;
 
 class ServerHandler : public QThread {
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(ServerHandler)
 	protected:
 		QString qsHostName;
 		QString qsUserName;
