@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -42,11 +42,13 @@ Settings::Settings() {
 	iTTSThreshold = 250;
 	iQuality = 6;
 	fVolume = 1.0f;
+	fOtherVolume = 0.5f;
 	iMinLoudness = 1000;
 	iVoiceHold = 50;
 	iJitterBufferSize = 1;
 	iFramesPerPacket = 2;
 	iNoiseSuppress = -30;
+	iIdleTime = 0;
 	vsVAD = SignalToNoise;
 	fVADmin = 0.80f;
 	fVADmax = 0.98f;
@@ -67,8 +69,11 @@ Settings::Settings() {
 	ceExpand = ChannelsWithPlayers;
 	ceChannelDrag = Ask;
 	bMinimalView = false;
+	bHideFrame = false;
 	bAlwaysOnTop = false;
 	bAskOnQuit = true;
+	bHideTray = true;
+	bUsage = true;
 
 	iOutputDelay = 5;
 
@@ -109,6 +114,9 @@ Settings::Settings() {
 	qcOverlayChannel = QColor(192,192,255,192);
 	qcOverlayChannelTalking = QColor(224,224,255,255);
 
+	iLCDPlayerViewMinColWidth = 50;
+	iLCDPlayerViewSplitterWidth = 2;
+
 	// Network settings
 	bTCPCompat = false;
 	bReconnect = true;
@@ -179,12 +187,14 @@ void Settings::load() {
 	SAVELOAD(iQuality, "audio/quality");
 	SAVELOAD(iMinLoudness, "audio/loudness");
 	SAVELOAD(fVolume, "audio/volume");
+	SAVELOAD(fOtherVolume, "audio/othervolume");
 	LOADENUM(vsVAD, "audio/vadsource");
 	SAVELOAD(fVADmin, "audio/vadmin");
 	SAVELOAD(fVADmax, "audio/vadmax");
 	SAVELOAD(iNoiseSuppress, "audio/noisesupress");
 	SAVELOAD(iVoiceHold, "audio/voicehold");
 	SAVELOAD(iOutputDelay, "audio/outputdelay");
+	SAVELOAD(iIdleTime, "audio/idletime");
 	SAVELOAD(fAudioMinDistance, "audio/mindistance");
 	SAVELOAD(fAudioMaxDistance, "audio/maxdistance");
 	SAVELOAD(fAudioRollOff, "audio/rolloff");
@@ -260,15 +270,23 @@ void Settings::load() {
 	SAVELOAD(bAlwaysOnTop, "ui/alwaysontop");
 	SAVELOAD(bAskOnQuit, "ui/askonquit");
 	SAVELOAD(bMinimalView, "ui/minimalview");
+	SAVELOAD(bHideFrame, "ui/hideframe");
 	SAVELOAD(bPlayerTop, "ui/playertop");
 	SAVELOAD(bFirstTime, "ui/firsttime");
 	SAVELOAD(qbaMainWindowGeometry, "ui/geometry");
 	SAVELOAD(qbaMainWindowState, "ui/state");
+	SAVELOAD(qbaMinimalViewGeometry, "ui/minimalviewgeometry");
+	SAVELOAD(qbaConfigGeometry, "ui/ConfigGeometry");
 	SAVELOAD(qbaSplitterState, "ui/splitter");
 	SAVELOAD(qbaHeaderState, "ui/header");
 	SAVELOAD(qsUsername, "ui/username");
 	SAVELOAD(iServerRow, "ui/serverrow");
 	SAVELOAD(bUpdateCheck, "ui/updatecheck");
+	SAVELOAD(bHideTray, "ui/hidetray");
+	SAVELOAD(bUsage, "ui/usage");
+
+	SAVELOAD(iLCDPlayerViewMinColWidth, "lcd/playerview/mincolwidth");
+	SAVELOAD(iLCDPlayerViewSplitterWidth, "lcd/playerview/splitterwidth");
 
 	int nshorts = g.qs->beginReadArray(QLatin1String("shortcuts"));
 	for (int i=0;i<nshorts;i++) {
@@ -284,6 +302,12 @@ void Settings::load() {
 		SAVELOAD(qmMessages[it.key()], "log");
 	}
 	g.qs->endArray();
+
+	g.qs->beginGroup(QLatin1String("lcd/devices"));
+	foreach(const QString &d, g.qs->childKeys()) {
+		qmLCDDevices.insert(d, g.qs->value(d, true).toBool());
+	}
+	g.qs->endGroup();
 }
 
 #undef SAVELOAD
@@ -300,12 +324,14 @@ void Settings::save() {
 	SAVELOAD(iQuality, "audio/quality");
 	SAVELOAD(iMinLoudness, "audio/loudness");
 	SAVELOAD(fVolume, "audio/volume");
+	SAVELOAD(fOtherVolume, "audio/othervolume");
 	SAVELOAD(vsVAD, "audio/vadsource");
 	SAVELOAD(fVADmin, "audio/vadmin");
 	SAVELOAD(fVADmax, "audio/vadmax");
 	SAVELOAD(iNoiseSuppress, "audio/noisesupress");
 	SAVELOAD(iVoiceHold, "audio/voicehold");
 	SAVELOAD(iOutputDelay, "audio/outputdelay");
+	SAVELOAD(iIdleTime, "audio/idletime");
 	SAVELOAD(fAudioMinDistance, "audio/mindistance");
 	SAVELOAD(fAudioMaxDistance, "audio/maxdistance");
 	SAVELOAD(fAudioRollOff, "audio/rolloff");
@@ -381,18 +407,25 @@ void Settings::save() {
 	SAVELOAD(bAlwaysOnTop, "ui/alwaysontop");
 	SAVELOAD(bAskOnQuit, "ui/askonquit");
 	SAVELOAD(bMinimalView, "ui/minimalview");
+	SAVELOAD(bHideFrame, "ui/hideframe");
 	SAVELOAD(bPlayerTop, "ui/playertop");
 	SAVELOAD(bFirstTime, "ui/firsttime");
 	SAVELOAD(qbaMainWindowGeometry, "ui/geometry");
 	SAVELOAD(qbaMainWindowState, "ui/state");
+	SAVELOAD(qbaMinimalViewGeometry, "ui/minimalviewgeometry");
+	SAVELOAD(qbaConfigGeometry, "ui/ConfigGeometry");
 	SAVELOAD(qbaSplitterState, "ui/splitter");
 	SAVELOAD(qbaHeaderState, "ui/header");
 	SAVELOAD(qsUsername, "ui/username");
 	SAVELOAD(iServerRow, "ui/serverrow");
 	SAVELOAD(bUpdateCheck, "ui/updatecheck");
+	SAVELOAD(bHideTray, "ui/hidetray");
+	SAVELOAD(bUsage, "ui/usage");
+
+	SAVELOAD(iLCDPlayerViewMinColWidth, "lcd/playerview/mincolwidth");
+	SAVELOAD(iLCDPlayerViewSplitterWidth, "lcd/playerview/splitterwidth");
 
 	g.qs->beginWriteArray(QLatin1String("shortcuts"));
-	int idx = 0;
 	for (ShortcutMap::const_iterator it = qmShortcuts.constBegin(); it != qmShortcuts.constEnd(); ++it) {
 		g.qs->setArrayIndex(it.key());
 		SAVELOAD(qmShortcuts[it.key()], "keys");
@@ -401,10 +434,19 @@ void Settings::save() {
 	g.qs->endArray();
 
 	g.qs->beginWriteArray(QLatin1String("messages"));
-	idx = 0;
 	for (QMap<int, quint32>::const_iterator it = qmMessages.constBegin(); it != qmMessages.constEnd(); ++it) {
 		g.qs->setArrayIndex(it.key());
 		SAVELOAD(qmMessages[it.key()], "log");
 	}
 	g.qs->endArray();
+
+	g.qs->beginGroup(QLatin1String("lcd/devices"));
+	foreach(const QString &d, qmLCDDevices.keys()) {
+		bool v = qmLCDDevices.value(d);
+		if (!v)
+			g.qs->setValue(d, v);
+		else
+			g.qs->remove(d);
+	}
+	g.qs->endGroup();
 }
