@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -47,10 +47,15 @@ VersionCheck::VersionCheck(bool autocheck, QObject *p) : QObject(p) {
 	quUrl.addQueryItem(QLatin1String("os"), QLatin1String("Win32"));
 #elif defined(Q_OS_MAC)
 	quUrl.addQueryItem(QLatin1String("os"), QLatin1String("MacOSX"));
+#else
+	quUrl.addQueryItem(QLatin1String("os"), QLatin1String("Unix"));
 #endif
+	if (! g.s.bUsage)
+		quUrl.addQueryItem(QLatin1String("nousage"), QLatin1String("1"));
 	if (autocheck)
 		quUrl.addQueryItem(QLatin1String("auto"), QLatin1String("1"));
 
+	quUrl.addQueryItem(QLatin1String("locale"), g.s.qsLanguage.isEmpty() ? QLocale::system().name() : g.s.qsLanguage);
 	QMetaObject::connectSlotsByName(this);
 
 	QFile f(qApp->applicationFilePath());
@@ -82,7 +87,7 @@ void VersionCheck::on_Agent_requestFinished(int id, bool error) {
 	if ((head.statusCode() == 200) && !error) {
 		QByteArray a=qhAgent->readAll();
 		if (a.size() > 0)
-			g.mw->msgBox(QLatin1String(a));
+			g.mw->msgBox(QString::fromUtf8(a));
 	} else if (bSilent) {
 		g.mw->msgBox(tr("Mumble failed to retrieve version information from the SourceForge server."));
 	}
