@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -184,7 +184,7 @@ void MurmurDBus::setTempGroups(int playerid, Channel *cChannel, const QStringLis
 
 	Group *g;
 	foreach(g, cChannel->qhGroups)
-	g->qsTemporary.remove(playerid);
+		g->qsTemporary.remove(playerid);
 
 	QString gname;
 	foreach(gname, groups) {
@@ -430,7 +430,7 @@ void MurmurDBus::getChannels(QList<ChannelInfo> &a) {
 		Channel *c = q.dequeue();
 		a << ChannelInfo(c);
 		foreach(c, c->qlChannels)
-		q.enqueue(c);
+			q.enqueue(c);
 	}
 }
 
@@ -705,7 +705,7 @@ void MurmurDBus::setACL(int id, const QList<ACLInfo> &acls, const QList<GroupInf
 		delete g;
 	}
 	foreach(a, cChannel->qlACL)
-	delete a;
+		delete a;
 	cChannel->qhGroups.clear();
 	cChannel->qlACL.clear();
 
@@ -745,7 +745,7 @@ void MurmurDBus::getBans(QList<BanInfo> &bi) {
 void MurmurDBus::setBans(const QList<BanInfo> &bans, const QDBusMessage &) {
 	server->qlBans.clear();
 	foreach(BanInfo bi, bans)
-	server->qlBans << QPair<quint32,int>(bi.address,bi.bits);
+		server->qlBans << QPair<quint32,int>(bi.address,bi.bits);
 	server->saveBans();
 }
 
@@ -834,11 +834,19 @@ void MurmurDBus::updateRegistration(const RegisteredPlayer &player, const QDBusM
 	}
 }
 
-void MurmurDBus::getTexture(int id, const QDBusMessage &, QByteArray &texture) {
+void MurmurDBus::getTexture(int id, const QDBusMessage &msg, QByteArray &texture) {
+	if (! server->isPlayerId(id)) {
+		qdbc.send(msg.createErrorReply("net.sourceforge.mumble.Error.playerid", "Invalid player id"));
+		return;
+	}
 	texture = server->getUserTexture(id);
 }
 
 void MurmurDBus::setTexture(int id, const QByteArray &texture, const QDBusMessage &msg) {
+	if (! server->isPlayerId(id)) {
+		qdbc.send(msg.createErrorReply("net.sourceforge.mumble.Error.playerid", "Invalid player id"));
+		return;
+	}
 	if (! server->setTexture(id, texture)) {
 		qdbc.send(msg.createErrorReply("net.sourceforge.mumble.Error.texture", "Invalid texture"));
 		return;
@@ -914,7 +922,7 @@ ChannelInfo::ChannelInfo(Channel *c) {
 	name = c->qsName;
 	parent = c->cParent ? c->cParent->iId : -1;
 	foreach(Channel *chn, c->qsPermLinks)
-	links << chn->iId;
+		links << chn->iId;
 }
 
 ACLInfo::ACLInfo(ChanACL *acl) {
@@ -1105,7 +1113,7 @@ void MetaDBus::rotateLogs(const QDBusMessage &msg) {
 }
 
 void MetaDBus::quit() {
-	qWarning("Quit requested from D-Bus");
+	qCritical("Quit requested from D-Bus");
 	QCoreApplication::instance()->quit();
 }
 
