@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -70,7 +70,7 @@ void Server::msgServerAuthenticate(Connection *cCon, MessageServerAuthenticate *
 
 	MessageServerReject msr;
 	bool ok = false;
-	bool nameok = Player::validateName(msg->qsUsername);
+	bool nameok = validatePlayerName(msg->qsUsername);
 
 	// Fetch ID and stored username.
 	// Since this may call DBus, which may recall our dbus messages, this function needs
@@ -179,7 +179,7 @@ void Server::msgServerAuthenticate(Connection *cCon, MessageServerAuthenticate *
 		sendMessage(cCon, &mca);
 
 		foreach(c, c->qlChannels)
-		q.enqueue(c);
+			q.enqueue(c);
 	}
 
 	foreach(c, chans) {
@@ -188,7 +188,7 @@ void Server::msgServerAuthenticate(Connection *cCon, MessageServerAuthenticate *
 			mcl.iId = c->iId;
 			mcl.ltType = MessageChannelLink::Link;
 			foreach(Channel *l, c->qhLinks.keys())
-			mcl.qlTargets << l->iId;
+				mcl.qlTargets << l->iId;
 			sendMessage(cCon, &mcl);
 		}
 	}
@@ -436,7 +436,7 @@ void Server::msgChannelAdd(Connection *cCon, MessageChannelAdd *msg) {
 		return;
 	}
 
-	if (! Channel::validateName(msg->qsName)) {
+	if (! validateChannelName(msg->qsName)) {
 		PERM_DENIED_TEXT("Illegal channel name");
 		return;
 	}
@@ -447,6 +447,13 @@ void Server::msgChannelAdd(Connection *cCon, MessageChannelAdd *msg) {
 		return;
 	}
 
+	foreach(Channel *sibling, p->qlChannels) {
+		if (sibling->qsName == msg->qsName) {
+			PERM_DENIED_TEXT("Duplicate channel name");
+			return;
+		}
+	}
+
 	Channel *c = addChannel(p, msg->qsName);
 	if (uSource->iId >= 0) {
 		Group *g = new Group(c, "admin");
@@ -490,7 +497,7 @@ void Server::msgChannelRename(Connection *cCon, MessageChannelRename *msg) {
 		return;
 	}
 
-	if (! Channel::validateName(msg->qsName)) {
+	if (! validateChannelName(msg->qsName)) {
 		PERM_DENIED_TEXT("Illegal channel name");
 		return;
 	}
@@ -501,6 +508,13 @@ void Server::msgChannelRename(Connection *cCon, MessageChannelRename *msg) {
 		return;
 	}
 
+	foreach(Channel *sibling, c->cParent->qlChannels) {
+		if (sibling->qsName == msg->qsName) {
+			PERM_DENIED_TEXT("Duplicate channel name");
+			return;
+		}
+	}
+
 	log(uSource, "Renamed channel %s to %s", qPrintable(c->qsName), qPrintable(msg->qsName));
 	c->qsName = msg->qsName;
 	updateChannel(c);
@@ -529,6 +543,13 @@ void Server::msgChannelMove(Connection *cCon, MessageChannelMove *msg) {
 		return;
 	}
 
+	foreach(Channel *sibling, np->qlChannels) {
+		if (sibling->qsName == c->qsName) {
+			PERM_DENIED_TEXT("Duplicate channel name");
+			return;
+		}
+	}
+
 	// Can't move to a subchannel of itself
 	Channel *p = np;
 	while (p) {
@@ -633,7 +654,7 @@ void Server::msgChannelLink(Connection *cCon, MessageChannelLink *msg) {
 		changed = oldset - newset;
 	}
 	foreach(l, changed)
-	mcl.qlTargets << l->iId;
+		mcl.qlTargets << l->iId;
 	sendAll(&mcl);
 }
 
@@ -661,7 +682,7 @@ void Server::msgTextMessage(Connection *cCon, MessageTextMessage *msg) {
 				c = q.dequeue();
 				chans.insert(c);
 				foreach(c, c->qlChannels)
-				q.enqueue(c);
+					q.enqueue(c);
 			}
 		}
 		foreach(c, chans) {
@@ -766,7 +787,7 @@ void Server::msgEditACL(Connection *cCon, MessageEditACL *msg) {
 		}
 
 		foreach(a, c->qlACL)
-		delete a;
+			delete a;
 
 		c->qhGroups.clear();
 		c->qlACL.clear();
