@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -97,7 +97,7 @@ MurmurIce::MurmurIce() {
 			qWarning("MurmurIce: Endpoint \"%s\" running", qPrintable(fromStdUtf8String(ep->toString())));
 		}
 	} catch (Ice::Exception &e) {
-		qWarning("MurmurIce: Initialization failed: %s", qPrintable(fromStdUtf8String(e.ice_name())));
+		qCritical("MurmurIce: Initialization failed: %s", qPrintable(fromStdUtf8String(e.ice_name())));
 	}
 }
 
@@ -158,7 +158,7 @@ static void channelToChannel(const ::Channel *c, Murmur::Channel &mc) {
 	mc.parent = c->cParent ? c->cParent->iId : -1;
 	mc.links.clear();
 	foreach(::Channel *chn, c->qsPermLinks)
-	mc.links.push_back(chn->iId);
+		mc.links.push_back(chn->iId);
 }
 
 static void ACLtoACL(const ::ChanACL *acl, Murmur::ACL &ma) {
@@ -574,7 +574,7 @@ static void impl_Server_setACL(const ::Murmur::AMD_Server_setACLPtr cb, int serv
 		delete g;
 	}
 	foreach(acl, channel->qlACL)
-	delete acl;
+		delete acl;
 
 	channel->qhGroups.clear();
 	channel->qlACL.clear();
@@ -718,6 +718,12 @@ static void impl_Server_verifyPassword(const ::Murmur::AMD_Server_verifyPassword
 
 static void impl_Server_getTexture(const ::Murmur::AMD_Server_getTexturePtr cb, int server_id,  ::Ice::Int playerid) {
 	NEED_SERVER;
+
+	if (! server->isPlayerId(playerid)) {
+		cb->ice_exception(InvalidPlayerException());
+		return;
+	}
+
 	const QByteArray &qba = server->getUserTexture(playerid);
 
 	::Murmur::Texture tex;
@@ -731,12 +737,18 @@ static void impl_Server_getTexture(const ::Murmur::AMD_Server_getTexturePtr cb,
 
 static void impl_Server_setTexture(const ::Murmur::AMD_Server_setTexturePtr cb, int server_id,  ::Ice::Int playerid,  const ::Murmur::Texture& tex) {
 	NEED_SERVER;
+
+	if (! server->isPlayerId(playerid)) {
+		cb->ice_exception(InvalidPlayerException());
+		return;
+	}
+
 	QByteArray qba(tex.size(), 0);
 	char *ptr = qba.data();
 	for (unsigned int i=0;i<tex.size();++i)
 		ptr[i] = tex[i];
 	if (! server->setTexture(playerid, qba))
-		cb->ice_exception(InvalidPlayerException());
+		cb->ice_exception(InvalidTextureException());
 	else
 		cb->ice_response();
 }
@@ -757,7 +769,7 @@ static void impl_Meta_getAllServers(const ::Murmur::AMD_Meta_getAllServersPtr cb
 	::Murmur::ServerList sl;
 
 	foreach(int id, ServerDB::getAllServers())
-	sl.push_back(idToProxy(id, adapter));
+		sl.push_back(idToProxy(id, adapter));
 	cb->ice_response(sl);
 }
 
@@ -774,7 +786,7 @@ static void impl_Meta_getBootedServers(const ::Murmur::AMD_Meta_getBootedServers
 	::Murmur::ServerList sl;
 
 	foreach(int id, meta->qhServers.keys())
-	sl.push_back(idToProxy(id, adapter));
+		sl.push_back(idToProxy(id, adapter));
 	cb->ice_response(sl);
 }
 
