@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -31,6 +31,8 @@
 #include <QtXml>
 
 #include "Server.h"
+#include "Version.h"
+#include "OSInfo.h"
 
 void Server::initRegister() {
 	http = NULL;
@@ -68,45 +70,51 @@ void Server::update() {
 	QDomElement root=doc.createElement(QLatin1String("server"));
 	doc.appendChild(root);
 
+	OSInfo::fillXml(doc, root, meta->qsOS, meta->qsOSVersion, qhaBind);
+
 	QDomElement tag;
 	QDomText t;
 
 	tag=doc.createElement(QLatin1String("name"));
 	root.appendChild(tag);
-
 	t=doc.createTextNode(qsRegName);
 	tag.appendChild(t);
 
 	tag=doc.createElement(QLatin1String("host"));
 	root.appendChild(tag);
-
 	t=doc.createTextNode(qsRegHost);
 	tag.appendChild(t);
 
 	tag=doc.createElement(QLatin1String("password"));
 	root.appendChild(tag);
-
 	t=doc.createTextNode(qsRegPassword);
 	tag.appendChild(t);
 
 	tag=doc.createElement(QLatin1String("port"));
 	root.appendChild(tag);
-
 	t=doc.createTextNode(QString::number(usPort));
 	tag.appendChild(t);
 
 	tag=doc.createElement(QLatin1String("url"));
 	root.appendChild(tag);
-
 	t=doc.createTextNode(qurlRegWeb.toString());
 	tag.appendChild(t);
 
 	tag=doc.createElement(QLatin1String("digest"));
 	root.appendChild(tag);
-
 	t=doc.createTextNode(getDigest());
 	tag.appendChild(t);
 
+	tag=doc.createElement(QLatin1String("users"));
+	root.appendChild(tag);
+	t=doc.createTextNode(QString::number(qhUsers.count()));
+	tag.appendChild(t);
+
+	tag=doc.createElement(QLatin1String("channels"));
+	root.appendChild(tag);
+	t=doc.createTextNode(QString::number(qhChannels.count()));
+	tag.appendChild(t);
+
 	qssReg = new QSslSocket(this);
 	qssReg->setLocalCertificate(qscCert);
 	qssReg->setPrivateKey(qskKey);
@@ -138,5 +146,5 @@ void Server::done(bool err) {
 
 void Server::regSslError(const QList<QSslError> &errs) {
 	foreach(const QSslError &e, errs)
-	log("Registration: SSL Handshake error: %s", qPrintable(e.errorString()));
+		log("Registration: SSL Handshake error: %s", qPrintable(e.errorString()));
 }
