@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -76,6 +76,7 @@ User::User(Server *p, QSslSocket *socket) : Connection(p, socket), Player() {
 
 
 Server::Server(int snum, QObject *p) : QThread(p) {
+	bValid = true;
 	iServerNum = snum;
 
 	readParams();
@@ -85,42 +86,47 @@ Server::Server(int snum, QObject *p) : QThread(p) {
 
 	connect(qtsServer, SIGNAL(newConnection()), this, SLOT(newClient()), Qt::QueuedConnection);
 
-	if (! qtsServer->listen(qhaBind, usPort))
+	if (! qtsServer->listen(qhaBind, usPort)) {
 		log("Server: TCP Listen on port %d failed",usPort);
+		bValid = false;
+	} else {
+		log("Server listening on port %d",usPort);
+	}
 
-	log("Server listening on port %d",usPort);
+	sUdpSocket = INVALID_SOCKET;
 
+	if (bValid) {
 #ifdef Q_OS_UNIX
-	sUdpSocket = ::socket(PF_INET, SOCK_DGRAM, 0);
+		sUdpSocket = ::socket(PF_INET, SOCK_DGRAM, 0);
 #else
-
 #ifndef SIO_UDP_CONNRESET
 #define SIO_UDP_CONNRESET _WSAIOW(IOC_VENDOR,12)
 #endif
-
-	sUdpSocket = ::WSASocket(AF_INET, SOCK_DGRAM, IPPROTO_UDP, NULL, 0, WSA_FLAG_OVERLAPPED);
-	DWORD dwBytesReturned = 0;
-	BOOL bNewBehaviour = FALSE;
-	if (WSAIoctl(sUdpSocket, SIO_UDP_CONNRESET, &bNewBehaviour, sizeof(bNewBehaviour), NULL, 0, &dwBytesReturned, NULL, NULL) == SOCKET_ERROR) {
-		log("Failed to set SIO_UDP_CONNRESET: %d", WSAGetLastError());
-	}
+		sUdpSocket = ::WSASocket(AF_INET, SOCK_DGRAM, IPPROTO_UDP, NULL, 0, WSA_FLAG_OVERLAPPED);
+		DWORD dwBytesReturned = 0;
+		BOOL bNewBehaviour = FALSE;
+		if (WSAIoctl(sUdpSocket, SIO_UDP_CONNRESET, &bNewBehaviour, sizeof(bNewBehaviour), NULL, 0, &dwBytesReturned, NULL, NULL) == SOCKET_ERROR) {
+			log("Failed to set SIO_UDP_CONNRESET: %d", WSAGetLastError());
+		}
 #endif
-	if (sUdpSocket == INVALID_SOCKET) {
-		log("Failed to create UDP Socket");
-	} else {
-		struct sockaddr_in addr;
-		memset(&addr, 0, sizeof(addr));
-		addr.sin_family = AF_INET;
-		addr.sin_port = htons(usPort);
-		addr.sin_addr.s_addr = htonl(qhaBind.toIPv4Address());
-		if (::bind(sUdpSocket, reinterpret_cast<sockaddr *>(&addr), sizeof(addr)) == SOCKET_ERROR) {
-			log("Failed to bind UDP Socket to port %d", usPort);
+		if (sUdpSocket == INVALID_SOCKET) {
+			log("Failed to create UDP Socket");
+			bValid = false;
 		} else {
+			struct sockaddr_in addr;
+			memset(&addr, 0, sizeof(addr));
+			addr.sin_family = AF_INET;
+			addr.sin_port = htons(usPort);
+			addr.sin_addr.s_addr = htonl(qhaBind.toIPv4Address());
+			if (::bind(sUdpSocket, reinterpret_cast<sockaddr *>(&addr), sizeof(addr)) == SOCKET_ERROR) {
+				log("Failed to bind UDP Socket to port %d", usPort);
+			} else {
 #ifdef Q_OS_UNIX
-			int val = IPTOS_PREC_FLASHOVERRIDE | IPTOS_LOWDELAY | IPTOS_THROUGHPUT;
-			if (setsockopt(sUdpSocket, IPPROTO_IP, IP_TOS, &val, sizeof(val)))
-				log("Server: Failed to set TOS for UDP Socket");
+				int val = IPTOS_PREC_FLASHOVERRIDE | IPTOS_LOWDELAY | IPTOS_THROUGHPUT;
+				if (setsockopt(sUdpSocket, IPPROTO_IP, IP_TOS, &val, sizeof(val)))
+					log("Server: Failed to set TOS for UDP Socket");
 #endif
+			}
 		}
 	}
 
@@ -137,9 +143,11 @@ Server::Server(int snum, QObject *p) : QThread(p) {
 	getBans();
 	readChannels();
 	readLinks();
-	initRegister();
 	initializeCert();
 
+	if (bValid)
+		initRegister();
+
 	dbus = new MurmurDBus(this);
 	if (MurmurDBus::qdbc.isConnected())
 		MurmurDBus::qdbc.registerObject(QString::fromLatin1("/%1").arg(iServerNum), this);
@@ -153,10 +161,11 @@ Server::~Server() {
 	terminate();
 	wait();
 	qrwlUsers.unlock();
+	if (sUdpSocket != INVALID_SOCKET)
 #ifdef Q_OS_UNIX
-	close(sUdpSocket);
+		close(sUdpSocket);
 #else
-	closesocket(sUdpSocket);
+		closesocket(sUdpSocket);
 #endif
 	log("Stopped");
 }
@@ -174,6 +183,8 @@ void Server::readParams() {
 	qsRegPassword = Meta::mp.qsRegPassword;
 	qsRegHost = Meta::mp.qsRegHost;
 	qurlRegWeb = Meta::mp.qurlRegWeb;
+	qrPlayerName = Meta::mp.qrPlayerName;
+	qrChannelName = Meta::mp.qrChannelName;
 
 	QString qsHost = getConf("host", QString()).toString();
 	if (! qsHost.isEmpty()) {
@@ -206,6 +217,9 @@ void Server::readParams() {
 	qsRegPassword = getConf("registerpassword", qsRegPassword).toString();
 	qsRegHost = getConf("registerhostname", qsRegHost).toString();
 	qurlRegWeb = QUrl(getConf("registerurl", qurlRegWeb.toString()).toString());
+
+	qrPlayerName=QRegExp(getConf("playername", qrPlayerName.pattern()).toString());
+	qrChannelName=QRegExp(getConf("channelname", qrChannelName.pattern()).toString());
 }
 
 void Server::setLiveConf(const QString &key, const QString &value) {
@@ -276,7 +290,12 @@ int BandwidthRecord::bandwidth() const {
 
 void Server::run() {
 	qint32 len;
+#if defined(__LP64__)
+	char encbuff[65536+8];
+	char *encrypted = encbuff + 4;
+#else
 	char encrypted[65536];
+#endif
 	char buffer[65536];
 
 	quint32 msgType = 0;
@@ -289,6 +308,9 @@ void Server::run() {
 	int fromlen;
 #endif
 
+	if (sUdpSocket == INVALID_SOCKET)
+		return;
+
 	while (bRunning) {
 #ifdef Q_OS_DARWIN
 		/*
@@ -306,7 +328,7 @@ void Server::run() {
 		if (ret == 0) {
 			continue;
 		} else if (ret == -1) {
-			qWarning("poll() failed: %s", strerror(errno));
+			qCritical("poll() failed: %s", strerror(errno));
 			break;
 		}
 #endif
@@ -412,7 +434,12 @@ bool Server::checkDecrypt(User *u, const char *encrypted, char *plain, unsigned
 
 void Server::sendMessage(User *u, const char *data, int len, QByteArray &cache) {
 	if ((u->saiUdpAddress.sin_port != 0) && u->csCrypt.isValid()) {
+#if defined(__LP64__)
+		STACKVAR(char, ebuffer, len+4+16);
+		char *buffer = reinterpret_cast<char *>(((reinterpret_cast<quint64>(ebuffer) + 8) & ~7) + 4);
+#else
 		STACKVAR(char, buffer, len+4);
+#endif
 		u->csCrypt.encrypt(reinterpret_cast<const unsigned char *>(data), reinterpret_cast<unsigned char *>(buffer), len);
 		::sendto(sUdpSocket, buffer, len+4, 0, reinterpret_cast<struct sockaddr *>(& u->saiUdpAddress), sizeof(u->saiUdpAddress));
 	} else {
@@ -517,7 +544,7 @@ void Server::newClient() {
 		quint32 base = adr.toIPv4Address();
 
 		if (meta->banCheck(adr)) {
-			log("Ignoring connection: %s:%d (Global ban)",qPrintable(sock->peerAddress().toString()),sock->peerPort());
+			log("Ignoring connection: %s:%d (Global ban)",qPrintable(addressToString(sock->peerAddress())),sock->peerPort());
 			sock->disconnectFromHost();
 			sock->deleteLater();
 			return;
@@ -529,7 +556,7 @@ void Server::newClient() {
 			int mask = 32 - ban.second;
 			mask = (1 << mask) - 1;
 			if ((base & ~mask) == (ban.first & ~mask)) {
-				log("Ignoring connection: %s:%d",qPrintable(sock->peerAddress().toString()),sock->peerPort());
+				log("Ignoring connection: %s:%d",qPrintable(addressToString(sock->peerAddress())),sock->peerPort());
 				sock->disconnectFromHost();
 				sock->deleteLater();
 				return;
@@ -558,7 +585,7 @@ void Server::newClient() {
 		connect(u, SIGNAL(message(QByteArray &)), this, SLOT(message(QByteArray &)));
 		connect(u, SIGNAL(handleSslErrors(const QList<QSslError> &)), this, SLOT(sslError(const QList<QSslError> &)));
 
-		log(u, "New connection: %s:%d",qPrintable(sock->peerAddress().toString()),sock->peerPort());
+		log(u, "New connection: %s:%d",qPrintable(addressToString(sock->peerAddress())),sock->peerPort());
 
 		sock->startServerEncryption();
 	}
@@ -648,7 +675,7 @@ void Server::checkTimeout() {
 	}
 	qrwlUsers.unlock();
 	foreach(User *u, qlClose)
-	u->disconnectSocket(true);
+		u->disconnectSocket(true);
 }
 
 void Server::tcpTransmitData(QByteArray a, unsigned int id) {
@@ -678,8 +705,8 @@ void Server::sendAll(Message *mMsg) {
 
 void Server::sendExcept(Message *mMsg, Connection *cCon) {
 	foreach(User *u, qhUsers)
-	if ((static_cast<Connection *>(u) != cCon) && (u->sState == Player::Authenticated))
-		u->sendMessage(mMsg);
+		if ((static_cast<Connection *>(u) != cCon) && (u->sState == Player::Authenticated))
+			u->sendMessage(mMsg);
 }
 
 void Server::removeChannel(Channel *chan, Player *src, Channel *dest) {
@@ -771,7 +798,25 @@ void Server::clearACLCache(Player *p) {
 			delete h;
 	} else {
 		foreach(ChanACL::ChanCache *h, acCache)
-		delete h;
+			delete h;
 		acCache.clear();
 	}
 }
+
+QString Server::addressToString(const QHostAddress &adr) {
+	if (Meta::mp.iObfuscate == 0)
+		return adr.toString();
+
+	quint32 num = adr.toIPv4Address() ^ Meta::mp.iObfuscate;
+
+	QHostAddress n(num);
+	return n.toString();
+}
+
+bool Server::validatePlayerName(const QString &name) {
+	return (qrPlayerName.exactMatch(name) && (name.length() <= 512));
+}
+
+bool Server::validateChannelName(const QString &name) {
+	return (qrChannelName.exactMatch(name) && (name.length() <= 512));
+}
