@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -64,7 +64,9 @@ struct BandwidthRecord {
 };
 
 class LogEmitter : public QObject {
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(LogEmitter)
 	signals:
 		void newLogEntry(const QString &msg);
 	public:
@@ -73,7 +75,9 @@ class LogEmitter : public QObject {
 };
 
 class SslServer : public QTcpServer {
+	private:
 		Q_OBJECT;
+		Q_DISABLE_COPY(SslServer)
 	protected:
 		QList<QSslSocket *> qlSockets;
 		void incomingConnection(int);
@@ -85,7 +89,9 @@ class SslServer : public QTcpServer {
 class Server;
 
 class User : public Connection, public Player {
+	private:
 		Q_OBJECT
+		Q_DISABLE_COPY(User)
 	protected:
 		Server *s;
 	public:
@@ -102,8 +108,9 @@ class ServerI;
 class Server : public QThread, public MessageHandler {
 		friend class DBus;
 		friend class Murmur::ServerI;
+	private:
 		Q_OBJECT;
-
+		Q_DISABLE_COPY(Server);
 	protected:
 		bool bRunning;
 
@@ -123,10 +130,15 @@ class Server : public QThread, public MessageHandler {
 		QString qsRegHost;
 		QUrl qurlRegWeb;
 
+		QRegExp qrPlayerName;
+		QRegExp qrChannelName;
+
 		QSslCertificate qscCert;
 		QSslKey qskKey;
 		QByteArray qbaPassPhrase;
 
+		bool bValid;
+
 		void readParams();
 
 		// Registration, implementation in Register.cpp
@@ -188,6 +200,9 @@ class Server : public QThread, public MessageHandler {
 		void fakeUdpPacket(Message *msg, Connection *source);
 		void run();
 
+		bool validateChannelName(const QString &name);
+		bool validatePlayerName(const QString &name);
+
 		bool checkDecrypt(User *u, const char *encrypted, char *plain, unsigned int cryptlen);
 
 		bool hasPermission(Player *p, Channel *c, ChanACL::Perm perm);
@@ -199,6 +214,8 @@ class Server : public QThread, public MessageHandler {
 
 		void setLiveConf(const QString &key, const QString &value);
 
+		QString addressToString(const QHostAddress &);
+
 #ifndef Q_OS_WIN
 		__attribute__((format(printf, 2, 3)))
 #endif
@@ -250,6 +267,7 @@ class Server : public QThread, public MessageHandler {
 		bool setName(int id, const QString &name);
 		bool setEmail(int id, const QString &email);
 		bool setTexture(int id, const QByteArray &texture);
+		bool isPlayerId(int id);
 		bool getRegistration(int id, QString &name, QString &email);
 		void addLink(Channel *c, Channel *l);
 		void removeLink(Channel *c, Channel *l);
