@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -450,7 +450,7 @@ int Server::registerPlayer(const QString &name) {
 	if (name.isEmpty())
 		return -1;
 
-	if (! Player::validateName(name))
+	if (! validatePlayerName(name))
 		return -1;
 
 	if (getUserID(name) >= 0)
@@ -538,6 +538,25 @@ QMap<int, QPair<QString, QString> > Server::getRegisteredPlayers(const QString &
 	return m;
 }
 
+bool Server::isPlayerId(int id) {
+	QString name, email;
+	int res = dbus->dbusGetRegistration(id, name, email);
+	if (res >= 0)
+		return (res > 0);
+
+	TransactionHolder th;
+
+	QSqlQuery &query = *th.qsqQuery;
+	SQLPREP("SELECT player_id FROM %1players WHERE server_id = ? AND player_id = ?");
+	query.addBindValue(iServerNum);
+	query.addBindValue(id);
+	SQLEXEC();
+	if (query.next()) {
+		return true;
+	}
+	return false;
+}
+
 bool Server::getRegistration(int id, QString &name, QString &email) {
 	int res = dbus->dbusGetRegistration(id, name, email);
 	if (res >= 0)
@@ -1008,7 +1027,7 @@ void Server::readChannels(Channel *p) {
 	query.clear();
 
 	foreach(c, kids)
-	readChannels(c);
+		readChannels(c);
 }
 
 void Server::readLinks() {
@@ -1078,9 +1097,9 @@ void Server::dumpChannel(const Channel *c) {
 	foreach(g, c->qhGroups) {
 		qWarning("Group %s (Inh %d  Able %d)", qPrintable(g->qsName), g->bInherit, g->bInheritable);
 		foreach(pid, g->qsAdd)
-		qWarning("Add %d", pid);
+			qWarning("Add %d", pid);
 		foreach(pid, g->qsRemove)
-		qWarning("Remove %d", pid);
+			qWarning("Remove %d", pid);
 	}
 	foreach(acl, c->qlACL) {
 		int allow = static_cast<int>(acl->pAllow);
@@ -1185,7 +1204,7 @@ void Server::dblog(const char *str) {
 
 	SQLPREP("INSERT INTO %1slog (server_id, msg) VALUES(?,?)");
 	query.addBindValue(iServerNum);
-	query.addBindValue(QLatin1String(str));
+	query.addBindValue(str);
 	SQLEXEC();
 }
 
