@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -121,7 +121,7 @@ void UnixMurmur::handleSigTerm() {
 	char tmp;
 	::read(iTermFd[1], &tmp, sizeof(tmp));
 
-	qWarning("Caught SIGTERM, exiting");
+	qCritical("Caught SIGTERM, exiting");
 
 	QCoreApplication::instance()->quit();
 
