@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2008, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -75,6 +75,9 @@ static void murmurMessageOutput(QtMsgType type, const char *msg) {
 		case QtWarningMsg:
 			c='W';
 			break;
+		case QtCriticalMsg:
+			c='C';
+			break;
 		case QtFatalMsg:
 			c='F';
 			break;
@@ -150,9 +153,9 @@ int main(int argc, char **argv) {
 	a.setQuitOnLastWindowClosed(false);
 
 	QIcon icon;
-	icon.addFile(QLatin1String(":/mumble.16x16.png"));
-	icon.addFile(QLatin1String(":/mumble.32x32.png"));
-	icon.addFile(QLatin1String(":/mumble.64x64.png"));
+	icon.addFile(QLatin1String(":/murmur.16x16.png"));
+	icon.addFile(QLatin1String(":/murmur.32x32.png"));
+	icon.addFile(QLatin1String(":/murmur.64x64.png"));
 	a.setWindowIcon(icon);
 #else
 	QCoreApplication a(argc, argv);
@@ -162,6 +165,9 @@ int main(int argc, char **argv) {
 	a.setOrganizationName("Mumble");
 	a.setOrganizationDomain("mumble.sourceforge.net");
 
+	QTextCodec::setCodecForLocale(QTextCodec::codecForName("UTF-8"));
+	QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
+
 #ifdef Q_OS_WIN
 	{
 		size_t reqSize;
@@ -240,6 +246,28 @@ int main(int argc, char **argv) {
 			       "  -version         Show version information.\n"
 			       "If no inifile is provided, murmur will search for one in \n"
 			       "default locations.", argv[0]);
+#ifdef Q_OS_UNIX
+		} else if (arg == "-descriptors") {
+			QAbstractEventDispatcher *ed = QAbstractEventDispatcher::instance();
+			if (QLatin1String(ed->metaObject()->className()) != QLatin1String("QEventDispatcherGlib"))
+				qWarning("Not running with glib. While you may be able to open more descriptors, sockets above %d will not work", FD_SETSIZE);
+			qWarning("Running descriptor test.");
+			int count;
+			QList<QFile *> ql;
+			for (count=0;count < 524288; ++count) {
+				QFile *qf = new QFile(a.applicationFilePath());
+				if (qf->open(QIODevice::ReadOnly))
+					ql << qf;
+				else
+					break;
+				if ((count & 511) == 0)
+					qWarning("%d descriptors...", count);
+			}
+			foreach(QFile *qf, ql)
+				delete qf;
+			ql.clear();
+			qFatal("Managed to open %d descriptors", count);
+#endif
 		} else {
 			detach = false;
 			qFatal("Unknown argument %s", argv[i]);
@@ -295,8 +323,12 @@ int main(int argc, char **argv) {
 		if (! qfLog->open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::Text)) {
 			delete qfLog;
 			qfLog = NULL;
+#ifdef Q_OS_UNIX
+			fprintf(stderr, "murmurd: failed to open logfile %s: no logging will be done\n",qPrintable(Meta::mp.qsLogfile));
+#else
 			qWarning("Failed to open logfile %s. Will not detach.",qPrintable(Meta::mp.qsLogfile));
 			detach = false;
+#endif
 		} else {
 			qfLog->setTextModeEnabled(true);
 			QFileInfo qfi(*qfLog);
@@ -365,8 +397,8 @@ int main(int argc, char **argv) {
 		if (! MurmurDBus::qdbc.isConnected()) {
 			qWarning("Failed to connect to D-Bus %s",qPrintable(Meta::mp.qsDBus));
 		}
-		new MetaDBus(meta);
 	}
+	meta->dbus = new MetaDBus(meta);
 	if (MurmurDBus::qdbc.isConnected()) {
 		if (! MurmurDBus::qdbc.registerObject("/", meta) || ! MurmurDBus::qdbc.registerService(Meta::mp.qsDBusService)) {
 			QDBusError e=MurmurDBus::qdbc.lastError();
@@ -380,6 +412,7 @@ int main(int argc, char **argv) {
 	IceStart();
 #endif
 
+	meta->getOSInfo();
 	meta->bootAll();
 
 	res=a.exec();
