@@ -42,6 +42,9 @@
 #include <errno.h>
 #define INVALID_SOCKET -1
 #define SOCKET_ERROR -1
+#ifdef Q_OS_DARWIN
+#include <poll.h>
+#endif
 #endif
 
 #ifdef Q_OS_WIN
@@ -58,4 +61,11 @@
 #define STACKVAR(type, varname, count) type varname[count]
 #endif
 
+#ifdef USE_ICE
+#include <boost/function.hpp>
+#include <boost/bind.hpp>
+#include <boost/shared_ptr.hpp>
+#include <boost/weak_ptr.hpp>
+#endif
+
 #endif
